@@ -1,20 +1,20 @@
-# $File: //local/member/autrijus/Win32-Exe/lib/Win32/Exe/Resource/Icon.pm $ $Author: autrijus $
-# $Revision: #6 $ $Change: 1130 $ $Date: 2004-02-17T15:40:29.640821Z $
+# $File: //member/autrijus/.vimrc $ $Author: autrijus $
+# $Revision: #14 $ $Change: 4137 $ $DateTime: 2003/02/08 11:41:59 $
 
 package Win32::Exe::Resource::Icon;
 
 use strict;
 use base 'Win32::Exe::Resource';
 use constant FORMAT => (
-    Width       => 'C',
-    Height      => 'C',
-    ColorCount      => 'C',
-    _           => 'C',
-    Planes      => 'v',
-    BitCount        => 'v',
-    ImageSize       => 'V',
-    I_RVA1      => 'v',
-    I_RVA2      => 'v',
+    Width	    => 'C',
+    Height	    => 'C',
+    ColorCount	    => 'C',
+    Reserved	    => 'C',
+    Planes	    => 'v',
+    BitCount	    => 'v',
+    ImageSize	    => 'V',
+    I_RVA1	    => 'v',
+    I_RVA2	    => 'v',
 );
 
 sub Id {
