@@ -1,23 +1,23 @@
-# $File: //local/member/autrijus/Win32-Exe/lib/Win32/Exe/ResourceEntry/Id.pm $ $Author: autrijus $
-# $Revision: #6 $ $Change: 1130 $ $Date: 2004-02-17T15:40:29.640821Z $
+# $File: //member/autrijus/.vimrc $ $Author: autrijus $
+# $Revision: #14 $ $Change: 4137 $ $DateTime: 2003/02/08 11:41:59 $
 
 package Win32::Exe::ResourceEntry::Id;
 
 use strict;
 use base 'Win32::Exe::ResourceEntry';
 use constant SUBFORMAT => (
-    Id          => 'V',
+    Id		    => 'V',
 );
 use constant RESOURCE_TYPES => [qw(
-    _       CURSOR          BITMAP          ICON        MENU
-    DIALOG  STRING          FONTDIR         FONT        ACCELERATOR
-    RCDATA  MESSAGETABLE    GROUP_CURSOR    _           GROUP_ICON
-    _       VERSION         DLGINCLUDE      _           PLUGPLAY
-    VXD     ANICURSOR       ANIICON         HTML        MANIFEST
+    _		CURSOR		BITMAP		ICON	    MENU
+    DIALOG	STRING		FONTDIR		FONT	    ACCELERATOR
+    RCDATA	MESSAGETABLE	GROUP_CURSOR	_	    GROUP_ICON
+    _		VERSION		DLGINCLUDE	_	    PLUGPLAY
+    VXD		ANICURSOR	ANIICON		HTML
 )];
 use constant RT_TO_ID => {
     map { ('RT_'.RESOURCE_TYPES->[$_] => $_) }
-    (0 .. $#{+RESOURCE_TYPES})
+	(0 .. $#{+RESOURCE_TYPES})
 };
 use constant ID_TO_RT => { reverse %{+RT_TO_ID} };
 
